@@ -4,7 +4,7 @@ use warnings;
 
 package Pod::Markdown;
 BEGIN {
-  $Pod::Markdown::VERSION = '1.103491';
+  $Pod::Markdown::VERSION = '1.110730';
 }
 # ABSTRACT: Convert POD to Markdown
 use parent qw(Pod::Parser);
@@ -22,7 +22,7 @@ sub _private {
         Text      => [],       # final text
         Indent    => 0,        # list indent levels counter
         ListType  => '-',      # character on every item
-        searching => undef,    # what are we searching for? (title, author etc.)
+        searching => ''   ,    # what are we searching for? (title, author etc.)
         Title     => undef,    # page title
         Author    => undef,    # page author
     };
@@ -60,6 +60,12 @@ sub _save {
     return;
 }
 
+sub _unsave {
+    my $parser = shift;
+    my $data = $parser->_private;
+    return pop @{ $data->{Text} };
+}
+
 sub _indent_text {
     my ($parser, $text) = @_;
     my $data   = $parser->_private;
@@ -100,7 +106,7 @@ sub command {
             } elsif ($paragraph =~ m{AUTHOR}xmsi) {
                 $data->{searching} = 'author';
             } else {
-                $data->{searching} = undef;
+                $data->{searching} = '';
             }
         }
     }
@@ -116,9 +122,21 @@ sub command {
 
         # decrement indent level
         $data->{Indent}--;
+        $data->{searching} = '';
     } elsif ($command =~ m{item}xms) {
-        $parser->_save(sprintf '%s %s',
-            $data->{ListType}, $parser->interpolate($paragraph, $line_num));
+        $paragraph = $parser->interpolate($paragraph, $line_num);
+        $paragraph =~ s{^\h* \* \h*}{}xms;
+
+        if ($data->{searching} eq 'listpara') {
+            $data->{searching} = 'listheadhuddled';
+        }
+        else {
+            $data->{searching} = 'listhead';
+        }
+
+        if (length $paragraph) {
+            $parser->textblock($paragraph, $line_num);
+        }
     }
 
     # ignore other commands
@@ -141,11 +159,18 @@ sub textblock {
     $paragraph = $parser->_clean_text($paragraph);
 
     # searching ?
-    if ($data->{searching}) {
-        if ($data->{searching} =~ m{title|author}xms) {
-            $data->{ ucfirst $data->{searching} } = $paragraph;
-            $data->{searching} = undef;
+    if ($data->{searching} =~ m{title|author}xms) {
+        $data->{ ucfirst $data->{searching} } = $paragraph;
+        $data->{searching} = '';
+    } elsif ($data->{searching} =~ m{listhead(huddled)?$}xms) {
+        my $is_huddled = $1;
+        $paragraph = sprintf '%s %s', $data->{ListType}, $paragraph;
+        if ($is_huddled) {
+            $paragraph = $parser->_unsave() . "\n" . $paragraph;
         }
+        $data->{searching} = 'listpara';
+    } elsif ($data->{searching} eq 'listpara') {
+        $data->{searching} = '';
     }
 
     # save the text
@@ -208,7 +233,7 @@ sub format_header {
 __END__
 =pod
 
-=for stopwords textblock thompsonclan
+=for stopwords textblock thompsonclan Pagaltzis
 
 =head1 NAME
 
@@ -216,7 +241,7 @@ Pod::Markdown - Convert POD to Markdown
 
 =head1 VERSION
 
-version 1.103491
+version 1.110730
 
 =head1 SYNOPSIS
 
@@ -279,7 +304,7 @@ The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see L<http://search.cpan.org/dist/Pod-Markdown/>.
 
-The development version lives at L<http://github.com/hanekomu/Pod-Markdown.git>
+The development version lives at L<http://github.com/hanekomu/Pod-Markdown>
 and may be cloned from L<git://github.com/hanekomu/Pod-Markdown.git>.
 Instead of sending patches, please fork this project using the standard
 git and github infrastructure.
@@ -300,6 +325,10 @@ Victor Moral <victor@taquiones.net>
 
 Ryan C. Thompson <rct at thompsonclan d0t org>
 
+=item *
+
+Aristotle Pagaltzis <pagaltzis@gmx.de>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
